<template>
    <div class="tree-table-container">
        <div class="box" ref="box">
            <div class="left">
                <!--左侧div内容-->
                <div class="common-tree-container">
                    <div class="common-tree-title">
                        <i class="el-icon-menu" /> 物资分类
                    </div>
                    <div class="common-tree-content">
                        <el-tree v-if="treeData.length" :highlight-current="true" ref="tree" node-key="name"
                            :expand-on-click-node="false" :data="treeData" :props="defaultProps" default-expand-all
                            @node-click="handleNodeClick" />
                    </div>
                </div>
            </div>
            <div class="resize" title="收缩侧边栏">
                ⋮
            </div>
            <div class="mid">
                <!--右侧div内容-->
                <div class="common-table-container">
                    <div class="bbsl-common-page">
                        <div class="bbsl-table-search">
                            <el-form v-model="queryParam" label-width="auto">
                                <el-row :gutter="10">
                                    <el-col :span="5">
                                        <el-form-item label="品名">
                                            <el-input v-model="querys[1].value" clearable placeholder="请输入品名" />
                                        </el-form-item>
                                    </el-col>
                                    <el-col :span="5">
                                        <el-form-item label="年月">
                                            <el-date-picker v-model="querys[2].value" value-format="yyyy-MM"
                                                type="month" placeholder="选择年月">
                                            </el-date-picker>
                                        </el-form-item>
                                    </el-col>
                                    <el-col :span="4">
                                        <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
                                        </el-button>
                                        <el-button icon="el-icon-refresh" @click="handleReset">重置
                                        </el-button>
                                    </el-col>
                                </el-row>
                            </el-form>
                        </div>
                        <div ref="contentPanel" class="bbsl-table-content">
                            <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
                                :style="{ width: '100%' }" :max-height="tableMaxHeight"
                                :cell-style="{ 'text-align': 'center' }"
                                :header-cell-style="{ 'text-align': 'center' }">
                                <el-table-column fixed type="index" width="55" label="序号" />
                                <el-table-column label="库存状态" show-overflow-tooltip>
                                    <template slot-scope="scope">
                                        <el-tooltip v-if="scope.row.quantity > scope.row.minNumber" class="item"
                                            effect="dark" content="充足" placement="right-end">
                                            <span style="color:#67c23a" class="el-icon-s-opportunity">
                                            </span>
                                        </el-tooltip>
                                        <el-tooltip v-else class="item" effect="dark" content="缺货"
                                            placement="right-end">
                                            <span style="color:#f56c6c" class="el-icon-s-opportunity"></span>
                                        </el-tooltip>
                                    </template>
                                </el-table-column>
                                <el-table-column prop="name" label="品名" show-overflow-tooltip>
                                    <template slot-scope="scope">
                                        <el-tag type="success">{{ scope.row.name }}</el-tag>
                                    </template>
                                </el-table-column>
                                <el-table-column prop="months" label="	统计月份" show-overflow-tooltip />
                                <el-table-column prop="unit" label="单位" width="100" show-overflow-tooltip />
                                <el-table-column prop="minNumber" label="最低库存" show-overflow-tooltip />
                                <el-table-column prop="quantity" label="库存数量" show-overflow-tooltip />
                                <el-table-column prop="amount" label="剩余价值" show-overflow-tooltip />
                                <el-table-column prop="warehouse" label="所属仓库" show-overflow-tooltip
                                    :formatter="formartWarehouseName" />
                            </el-table>
                            <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
                                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                                :page-size="queryParam.pageBean.pageSize"
                                layout="total, sizes, prev, pager, next, jumper" :total="total"
                                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </div>
</template>
<script>
import { dragControllerDiv } from './api/dragControllerDiv'
import api from '@/api/device/materialAnalysis'
import quantityManage from '@/views/Manage/material/api/materialQuantityManage.js'
import { TableMixin } from '@/mixins/tableMixin'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import ebsTreeSelect from '@/views/Manage/components/SelectTree.vue'

export default {
    name: 'MaterialAccoutManage',
    components: {
        ebsTreeSelect
    },
    mixins: [TableMixin],
    data() {
        return {
            flowData: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    showTotal: true
                },
                querys: [],
                sorter: [
                    {
                        direction: 'ASC',
                        property: 'forTheDate'
                    }
                ]
            },
            flowTotal: '',
            getQuantityID: '',
            titles: '',
            search: '',
            tableData: [],
            detailsData: [],
            detailDialogVisible: false,
            showFormDias: false,
            treeData: [
                { code: '0', id: 0, name: '物资分类信息', parentId: 0, children: [] }
            ],
            defaultProps: {
                value: 'id',
                label: 'name',
                parentId: 'parentId',
                code: 'code',
                children: 'children'
            },
            data: [],
            treeNode: {
                code: '0',
                id: 0,
                name: '物资分类信息',
                parentId: 0,
                children: []
            },
            updateTreeNode: null,
            url: {},
            querys: [
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'm.class_Id_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'm.name_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'queryMonth ',
                    relation: 'AND',
                    value: ''
                },


            ],
            warehouses: []
        }
    },
    watch: {
        filterText(val) {
            // console.log(val)
            this.$refs.tree.filter(val)
        }
    },
    created() {
        this.warehouses = dictContracts.getDictItemsFromCache('cmgt_ckmc')
    },
    mounted() {
        dragControllerDiv()
        this.$refs['tree'].setCurrentKey('物资分类信息')
        this.getTreen()
    },
    methods: {
        handleReset() {
            this.querys[1].value = ''
            this.querys[2].value = ''
            this.loadData()
        },
        handleClose() {
            this.detailDialogVisible = false
        },
        // 树查询
        getTreen() {
            quantityManage.loadAllClass({}, res => {
                console.log(res)
                this.treeData[0].children = res.value
                this.$set(this.treeData)
            })
        },
        reload() {
            this.treeData = [
                { code: '', id: 0, name: '物资管理', parentId: 0, children: [] }
            ]
            this.$set(this.treeData)
            this.getTreen()
            this.loadData()
        },
        // 重置
        clearQuerys() {
            this.querys[0].value = ''
            this.querys[1].value = ''
            this.querys[2].value = ''
        },
        // 分页查询物资信息
        loadData(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            this.tableData = []
            this.queryParam.querys = []
            this.queryParam.params = {
                queryMonth: ''
            }
            // this.queryParam.sorter = [
            //   {
            //     direction: 'ASC',
            //     property: 'sn'
            //   }
            // ]
            if (this.querys[0].value) {
                this.queryParam.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.queryParam.querys.push(this.querys[1])
            }
            if (this.querys[2].value) {
                this.queryParam.params.queryMonth = this.querys[2].value
            }
            api.inventoryQuery(this.queryParam, res => {
                if (res.rows) {
                    this.total = res.total
                    this.tableData = res.rows
                    this.$set(this.tableData)
                    this.loading = false
                }

            })
        },
        handleNodeClick(data) {
            // 点击分类树节点
            this.treeNode = data

            this.querys[0].value = this.treeNode.id
            this.loadData(1)
        },
        formartWarehouseName(row, column, cellValue, index) {
            var obj = this.warehouses.find(function (item) {
                if (item.value === row.warehouse) {
                    return item
                }
            })
            if (obj !== undefined) {
                return obj.name
            } else {
                return ''
            }
        },


        formatterDate(row, column, cellValue, index) {
            var date = new Date(row.inoutDate)
            var month =
                date.getMonth() + 1 < 10
                    ? '0' + (date.getMonth() + 1)
                    : date.getMonth() + 1
            var currentDate =
                date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
            return date.getFullYear() + '-' + month + '-' + currentDate
        },
        getSummaries(param) {
            const { columns, data } = param
            const sums = []
            columns.forEach((column, index) => {
                if (index === 0) {
                    sums[index] = '总计'
                    return
                }
                if (index === 1 || index === 2 || index === 3 || index === 6) {
                    sums[index] = ''
                    return
                }

                const values = data.map(item => {
                    if (index === 4 && item.type === '0') {
                        return Number(item[column.property])
                    } else if (index === 5 && item.type === '1') {
                        return Number(item[column.property])
                    } else {
                        return 0
                    }
                })
                if (!values.every(value => isNaN(value))) {
                    sums[index] = values.reduce((prev, curr) => {
                        const value = Number(curr)
                        if (!isNaN(value)) {
                            return prev + curr
                        } else {
                            return prev
                        }
                    }, 0)
                    sums[index] += ''
                } else {
                    sums[index] = 'N/A'
                }
            })
            return sums
        }
    }
}
</script>
<style scoped>
/* 拖拽相关样式 */
/*包围div样式*/
.box {
    width: 100%;
    height: 100%;
    margin: 1% 0px;
    overflow: hidden;
    box-shadow: -1px 9px 10px 3px rgba(0, 0, 0, 0.11);
}

/*左侧div样式*/
.left {
    width: calc(16% - 10px);
    /*左侧初始化宽度*/
    height: 100%;
    background: #ffffff;
    float: left;
}

/*拖拽区div样式*/
.resize {
    cursor: col-resize;
    float: left;
    position: relative;
    top: 45%;
    background-color: #d6d6d6;
    border-radius: 5px;
    margin-top: -10px;
    width: 10px;
    height: 50px;
    background-size: cover;
    background-position: center;
    /*z-index: 99999;*/
    font-size: 32px;
    color: white;
}

/*拖拽区鼠标悬停样式*/
.resize:hover {
    color: #444444;
}

/*右侧div'样式*/
.mid {
    float: left;
    width: 84%;
    /*右侧初始化宽度*/
    height: 100%;
    background: #fff;
    box-shadow: -1px 4px 5px 3px rgba(0, 0, 0, 0.11);
}
</style>
<style lang="scss" scoped>
::v-deep .el-dialog {
    padding-bottom: 30px;
}

.common-tree-container ::v-deep .el-tree {
    border: none;
}

.outbound-details {
    height: 460px;
    overflow-y: scroll;
}
</style>